@@ -787,7 +787,7 @@ class TachyonRT(SageObject):
             sage: tgen.str()[30:40]
             'resolution'
             sage: t(tgen.str(), outfile=os.devnull)
-            tachyon ...
+            ...tachyon ...
             Tachyon Parallel/Multiprocessor Ray Tracer...
 
         TESTS::
